@@ -6,7 +6,7 @@
  * Copyright (C) 2005  Vincent Seynhaeve
  * Copyright (C) 2005  Benoit Mortier
  *
- * ID: $$Id: getxls.php 14816 2009-11-16 08:51:42Z hickert $$
+ * ID: $$Id: getxls.php 19199 2010-07-29 07:52:09Z hickert $$
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -445,21 +445,6 @@ function dump_ldap ($mode= 0)
   }
   elseif($mode == 4){ // IVBB LDIF Export
     $dn =  base64_decode($_GET['dn']);
-    /*$display= $ldap->gen_ldif($dn,"(objectClass=ivbbentry)",array(
-      "GouvernmentOrganizationalUnit","houseIdentifier","vocation",
-      "ivbbLastDeliveryCollective","gouvernmentOrganizationalPersonLocality",
-      "gouvernmentOrganizationalUnitDescription","gouvernmentOrganizationalUnitSubjectArea",
-      "functionalTitle","role","certificateSerialNumber","userCertificate","publicVisible",
-      "telephoneNumber","seeAlso","description","title","x121Address","registeredAddress",
-      "destinationIndicator","preferredDeliveryMethod","telexNumber","teletexTerminalIdentifier",
-      "telephoneNumber","internationaliSDNNumber","facsimileTelephoneNumber","street",
-      "postOfficeBox","postalCode","postalAddress","physicalDeliveryOfficeName","ou",
-      "st","l","audio","businessCategory","carLicense","departmentNumber","displayName",
-      "employeeNumber","employeeType","givenName","homePhone","homePostalAddress",
-      "initials","jpegPhoto","labeledURI","mail","manager","mobile","o","pager","photo",
-      "roomNumber","secretary","userCertificate","x500uniqueIdentifier","preferredLanguage",
-      "userSMIMECertificate","userPKCS12"));*/
-
     echo $display;
   }
 }
